API reference
=============

.. toctree::
   :maxdepth: 2

   core
   common_msgs
   auth

.. toctree::
   :maxdepth: 2
   :caption: I/O integrations

   blocking
   threading
   trio
   asyncio
   io_exceptions
